/*
 * Each file must start with this include.
 * File containes global settings.
 */
#include "settings.h"

/*
 * Main includes here.
 */
#include "commands.h"

/*
 * This file is autogenerated.
 * Changes made to this file can be overwritten.
 */

#if defined(__cplusplus)
extern "C"
{
#endif

typedef struct
{
  uint32_t  Command;
  uint8_t   InputSize;
  uint8_t   OutputSize;

} lengths_t;

static lengths_t Lengths[] =
{
  /*
   * Command code, input size, output size
   */
  { REST_CMD,   4,    4 },
  { WKEY_CMD,   46,    15 },
  { CONN_CMD,   14,    15 },
  { DISC_CMD,   14,    15 },
  { WDAT_CMD,   142,    4 },
  { GETI_CMD,   4,    36 },
  { GBLV_CMD,   4,    10 },
  { HASF_CMD,   4,    15 },
  { GOFW_CMD,   4,    15 },
  { IRND_CMD,   4,    24 },
  { SSER_CMD,   50,    4 },
  { GSER_CMD,   4,    10 },
  { UPDF_CMD,   4,    4 },
  { GETS_CMD,   4,    54 },
  { GDMY_CMD,   4,    10 },
  { SDMY_CMD,   10,    4 },
  { GINF_CMD,   4,    78 },
  { RBLD_CMD,   4,    4 },
  { 0, 0, 0 }   // End of array must be always
};

/*
 * Global structure with settings which is applied by the accessors.
 */
settings_storage_t Commands_SettingsStorage;

/*
 * This function is a lookup routine to get input data length in the packet.
 * If command is listed in the Lengths[] - it returns corresponding
 * data length. If not - it returns default command length.
 */
uint16_t Commands_GetInputSize(uint32_t cmd)
{
  for (uint32_t i = 0; Lengths[i].Command; i++)
  {
    if (cmd == Lengths[i].Command)
      return Lengths[i].InputSize;
  }

  return _COMMAND_LENGTH;
}

/*
 * This function is a lookup routine to get output data length in the packet.
 * If command is listed in the Lengths[] - it returns corresponding
 * data length. If not - it returns zero, which means that invalid
 * command is received.
 */
uint16_t Commands_GetOutputSize(uint32_t cmd)
{
  for (uint32_t i = 0; Lengths[i].Command; i++)
  {
    if (cmd == Lengths[i].Command)
      return Lengths[i].OutputSize;
  }

  return 0;
}

#if defined(__cplusplus)
};
#endif
